=== modified file 'drizzled/table.cc'
--- drizzled/table.cc	2008-09-19 11:49:17 +0000
+++ drizzled/table.cc	2008-10-09 08:33:03 +0000
@@ -1452,13 +1452,20 @@
 
   /* 
     Step 2: Setup thd for parsing.
+    1) make Item objects be created in the memory allocated for the Table
+       object (not TABLE_SHARE)
+    2) ensure that created Item's are not put on to thd->free_list 
+       (which is associated with the parsed statement and hence cleared after 
+       the parsing)
+    3) setup a flag in the LEX structure to allow "PARSE_VCOL_EXPR" 
+       to be parsed as a SQL command.
   */
-  Query_arena *backup_stmt_arena_ptr= thd->stmt_arena;
-  Query_arena backup_arena;
-  Query_arena vcol_arena(&table->mem_root, Query_arena::INITIALIZED);
-  thd->set_n_backup_active_arena(&vcol_arena, &backup_arena);
-  thd->stmt_arena= &vcol_arena;
-
+  MEM_ROOT **root_ptr, *old_root;
+  Item *backup_free_list= thd->free_list;
+  root_ptr= (MEM_ROOT **)pthread_getspecific(THR_MALLOC);
+  old_root= *root_ptr;
+  *root_ptr= &table->mem_root;
+  thd->free_list= NULL;
   thd->lex->parse_vcol_expr= true;
 
   /* 
@@ -1489,17 +1496,17 @@
     field->vcol_info= NULL;
     goto parse_err;
   }
-  thd->stmt_arena= backup_stmt_arena_ptr;
-  thd->restore_active_arena(&vcol_arena, &backup_arena);
-  field->vcol_info->item_free_list= vcol_arena.free_list;
+  field->vcol_info->item_free_list= thd->free_list;
+  thd->free_list= backup_free_list;
+  *root_ptr= old_root;
 
   return(false);
 
 parse_err:
   thd->lex->parse_vcol_expr= false;
   thd->free_items();
-  thd->stmt_arena= backup_stmt_arena_ptr;
-  thd->restore_active_arena(&vcol_arena, &backup_arena);
+  *root_ptr= old_root;
+  thd->free_list= backup_free_list;
   return(true);
 }
 

=== modified file 'tests/suite/vcol/inc/vcol_supported_sql_funcs_main.inc'
--- tests/suite/vcol/inc/vcol_supported_sql_funcs_main.inc	2008-09-19 11:49:17 +0000
+++ tests/suite/vcol/inc/vcol_supported_sql_funcs_main.inc	2008-10-09 08:33:03 +0000
@@ -400,7 +400,7 @@
 --source suite/vcol/inc/vcol_supported_sql_funcs.inc
 
 --echo # LIKE
-let $cols = a varchar(10), b virtual bool as (a like 'H%o');
+let $cols = a varchar(10), b virtual int as (a like 'H%o');
 let $values1 = 'Hello',default;
 let $values2 = 'MySQL',default;
 let $rows = 2;
@@ -446,7 +446,7 @@
 --source suite/vcol/inc/vcol_supported_sql_funcs.inc
 
 --echo # NOT LIKE
-let $cols = a varchar(10), b virtual bool as (a not like 'H%o');
+let $cols = a varchar(10), b virtual int as (a not like 'H%o');
 let $values1 = 'Hello',default;
 let $values2 = 'MySQL',default;
 let $rows = 2;
@@ -519,7 +519,7 @@
 --source suite/vcol/inc/vcol_supported_sql_funcs.inc
 
 --echo # STRCMP()
-let $cols = a varchar(9), b varchar(9), c virtual tinyint as (strcmp(a,b));
+let $cols = a varchar(9), b varchar(9), c virtual int as (strcmp(a,b));
 let $values1 = 'Hello','Hello', default;
 let $values2 = 'Hello','Hello1', default;
 let $rows = 2;
@@ -605,14 +605,14 @@
 --echo #
 
 --echo # AND
-let $cols = a int, b virtual bool as (a>0 and a<2);
+let $cols = a int, b virtual int as (a>0 and a<2);
 let $values1 = -1,default;
 let $values2 = 1,default;
 let $rows = 2;
 --source suite/vcol/inc/vcol_supported_sql_funcs.inc
 
 --echo # BETWEEN ... AND ... 
-let $cols = a int, b virtual bool as (a between 0 and 2);
+let $cols = a int, b virtual int as (a between 0 and 2);
 let $values1 = -1,default;
 let $values2 = 1,default;
 let $rows = 2;
@@ -633,7 +633,7 @@
 --source suite/vcol/inc/vcol_supported_sql_funcs.inc
 
 --echo # <=>
-let $cols = a int, b int, c virtual bool as (a <=> b);
+let $cols = a int, b int, c virtual int as (a <=> b);
 let $values1 = 1,1,default;
 let $values2 = NULL,NULL,default;
 let $values3 = 1,NULL,default;
@@ -641,42 +641,42 @@
 --source suite/vcol/inc/vcol_supported_sql_funcs.inc
 
 --echo # =
-let $cols = a varchar(10), b varchar(10), c virtual bool as (a=b);
+let $cols = a varchar(10), b varchar(10), c virtual int as (a=b);
 let $values1 = 'a','b',default;
 let $values2 = 'a','a',default;
 let $rows = 2;
 --source suite/vcol/inc/vcol_supported_sql_funcs.inc
 
 --echo # >=
-let $cols = a varchar(10), b varchar(10), c virtual bool as (a >= b);
+let $cols = a varchar(10), b varchar(10), c virtual int as (a >= b);
 let $values1 = 'a','b',default;
 let $values2 = 'a','a',default;
 let $rows = 2;
 --source suite/vcol/inc/vcol_supported_sql_funcs.inc
 
 --echo # >
-let $cols = a varchar(10), b varchar(10), c virtual bool as (a > b);
+let $cols = a varchar(10), b varchar(10), c virtual int as (a > b);
 let $values1 = 'a','b',default;
 let $values2 = 'a','a',default;
 let $rows = 2;
 --source suite/vcol/inc/vcol_supported_sql_funcs.inc
 
 --echo # IS NOT NULL
-let $cols = a int, b virtual bool as (a is not null);
+let $cols = a int, b virtual int as (a is not null);
 let $values1 = 1,default;
 let $values2 = NULL,default;
 let $rows = 2;
 --source suite/vcol/inc/vcol_supported_sql_funcs.inc
 
 --echo # IS NULL
-let $cols = a int, b virtual bool as (a is null);
+let $cols = a int, b virtual int as (a is null);
 let $values1 = 1,default;
 let $values2 = NULL,default;
 let $rows = 2;
 --source suite/vcol/inc/vcol_supported_sql_funcs.inc
 
 --echo # <=
-let $cols = a varchar(10), b varchar(10), c virtual bool as (a <= b);
+let $cols = a varchar(10), b varchar(10), c virtual int as (a <= b);
 let $values1 = 'b','a',default;
 let $values2 = 'b','b',default;
 let $values3 = 'b','c',default;
@@ -684,7 +684,7 @@
 --source suite/vcol/inc/vcol_supported_sql_funcs.inc
 
 --echo # <
-let $cols = a varchar(10), b varchar(10), c virtual bool as (a < b);
+let $cols = a varchar(10), b varchar(10), c virtual int as (a < b);
 let $values1 = 'b','a',default;
 let $values2 = 'b','b',default;
 let $values3 = 'b','c',default;
@@ -692,14 +692,14 @@
 --source suite/vcol/inc/vcol_supported_sql_funcs.inc
 
 --echo # NOT BETWEEN ... AND ...
-let $cols = a int, b virtual bool as (a not between 0 and 2);
+let $cols = a int, b virtual int as (a not between 0 and 2);
 let $values1 = -1,default;
 let $values2 = 1,default;
 let $rows = 2;
 --source suite/vcol/inc/vcol_supported_sql_funcs.inc
 
 --echo # <>
-let $cols = a varchar(10), b varchar(10), c virtual bool as (a <> b);
+let $cols = a varchar(10), b varchar(10), c virtual int as (a <> b);
 let $values1 = 'b','a',default;
 let $values2 = 'b','b',default;
 let $values3 = 'b','c',default;
@@ -707,7 +707,7 @@
 --source suite/vcol/inc/vcol_supported_sql_funcs.inc
 
 --echo # !=
-let $cols = a varchar(10), b varchar(10), c virtual bool as (a != b);
+let $cols = a varchar(10), b varchar(10), c virtual int as (a != b);
 let $values1 = 'b','a',default;
 let $values2 = 'b','b',default;
 let $values3 = 'b','c',default;
@@ -1013,18 +1013,16 @@
 --echo # CAST FUNCTIONS AND OPERATORS
 --echo #
 
---echo # CAST()
-let $cols = a int, b virtual int as (cast(a as unsigned));
-let $values1 = 1,default;
-let $values2 = -1,default;
-let $rows = 2;
+#--echo # CAST()
+let $cols = a varchar(32), b virtual datetime as (cast(a as datetime));
+let $values1 = '2008-10-09',default;
+let $rows = 1;
 --source suite/vcol/inc/vcol_supported_sql_funcs.inc
 
---echo # Convert()
-let $cols = a int, b virtual int as (convert(a,unsigned));
-let $values1 = 1,default;
-let $values2 = -1,default;
-let $rows = 2;
+#--echo # Convert()
+let $cols = a varchar(32), b virtual datetime as (convert(a, datetime));
+let $values1 = '2008-10-09',default;
+let $rows = 1;
 --source suite/vcol/inc/vcol_supported_sql_funcs.inc
 
 --echo #

=== modified file 'tests/suite/vcol/r/vcol_supported_sql_funcs_innodb.result'
--- tests/suite/vcol/r/vcol_supported_sql_funcs_innodb.result	2008-09-19 11:49:17 +0000
+++ tests/suite/vcol/r/vcol_supported_sql_funcs_innodb.result	2008-10-09 08:33:03 +0000
@@ -981,12 +981,12 @@
 set sql_warnings = 0;
 # LIKE
 set sql_warnings = 1;
-create table t1 (a varchar(10), b virtual bool as (a like 'H%o'));
+create table t1 (a varchar(10), b virtual int as (a like 'H%o'));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` varchar(10),
-  `b` VIRTUAL tinyint(1) AS (a like 'H%o')
+  `b` VIRTUAL int AS (a like 'H%o')
 ) ENGINE=InnoDB
 insert into t1 values ('Hello',default);
 insert into t1 values ('MySQL',default);
@@ -1096,12 +1096,12 @@
 set sql_warnings = 0;
 # NOT LIKE
 set sql_warnings = 1;
-create table t1 (a varchar(10), b virtual bool as (a not like 'H%o'));
+create table t1 (a varchar(10), b virtual int as (a not like 'H%o'));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` varchar(10),
-  `b` VIRTUAL tinyint(1) AS (a not like 'H%o')
+  `b` VIRTUAL int AS (a not like 'H%o')
 ) ENGINE=InnoDB
 insert into t1 values ('Hello',default);
 insert into t1 values ('MySQL',default);
@@ -1278,13 +1278,13 @@
 set sql_warnings = 0;
 # STRCMP()
 set sql_warnings = 1;
-create table t1 (a varchar(9), b varchar(9), c virtual tinyint as (strcmp(a,b)));
+create table t1 (a varchar(9), b varchar(9), c virtual int as (strcmp(a,b)));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` varchar(9),
   `b` varchar(9),
-  `c` VIRTUAL tinyint(4) AS (strcmp(a,b))
+  `c` VIRTUAL int AS (strcmp(a,b))
 ) ENGINE=InnoDB
 insert into t1 values ('Hello','Hello', default);
 insert into t1 values ('Hello','Hello1', default);
@@ -1479,12 +1479,12 @@
 #
 # AND
 set sql_warnings = 1;
-create table t1 (a int, b virtual bool as (a>0 and a<2));
+create table t1 (a int, b virtual int as (a>0 and a<2));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` int,
-  `b` VIRTUAL tinyint(1) AS (a>0 and a<2)
+  `b` VIRTUAL int AS (a>0 and a<2)
 ) ENGINE=InnoDB
 insert into t1 values (-1,default);
 insert into t1 values (1,default);
@@ -1496,12 +1496,12 @@
 set sql_warnings = 0;
 # BETWEEN ... AND ... 
 set sql_warnings = 1;
-create table t1 (a int, b virtual bool as (a between 0 and 2));
+create table t1 (a int, b virtual int as (a between 0 and 2));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` int,
-  `b` VIRTUAL tinyint(1) AS (a between 0 and 2)
+  `b` VIRTUAL int AS (a between 0 and 2)
 ) ENGINE=InnoDB
 insert into t1 values (-1,default);
 insert into t1 values (1,default);
@@ -1547,13 +1547,13 @@
 set sql_warnings = 0;
 # <=>
 set sql_warnings = 1;
-create table t1 (a int, b int, c virtual bool as (a <=> b));
+create table t1 (a int, b int, c virtual int as (a <=> b));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` int,
   `b` int,
-  `c` VIRTUAL tinyint(1) AS (a <=> b)
+  `c` VIRTUAL int AS (a <=> b)
 ) ENGINE=InnoDB
 insert into t1 values (1,1,default);
 insert into t1 values (NULL,NULL,default);
@@ -1567,13 +1567,13 @@
 set sql_warnings = 0;
 # =
 set sql_warnings = 1;
-create table t1 (a varchar(10), b varchar(10), c virtual bool as (a=b));
+create table t1 (a varchar(10), b varchar(10), c virtual int as (a=b));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` varchar(10),
   `b` varchar(10),
-  `c` VIRTUAL tinyint(1) AS (a=b)
+  `c` VIRTUAL int AS (a=b)
 ) ENGINE=InnoDB
 insert into t1 values ('a','b',default);
 insert into t1 values ('a','a',default);
@@ -1585,13 +1585,13 @@
 set sql_warnings = 0;
 # >=
 set sql_warnings = 1;
-create table t1 (a varchar(10), b varchar(10), c virtual bool as (a >= b));
+create table t1 (a varchar(10), b varchar(10), c virtual int as (a >= b));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` varchar(10),
   `b` varchar(10),
-  `c` VIRTUAL tinyint(1) AS (a >= b)
+  `c` VIRTUAL int AS (a >= b)
 ) ENGINE=InnoDB
 insert into t1 values ('a','b',default);
 insert into t1 values ('a','a',default);
@@ -1603,13 +1603,13 @@
 set sql_warnings = 0;
 # >
 set sql_warnings = 1;
-create table t1 (a varchar(10), b varchar(10), c virtual bool as (a > b));
+create table t1 (a varchar(10), b varchar(10), c virtual int as (a > b));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` varchar(10),
   `b` varchar(10),
-  `c` VIRTUAL tinyint(1) AS (a > b)
+  `c` VIRTUAL int AS (a > b)
 ) ENGINE=InnoDB
 insert into t1 values ('a','b',default);
 insert into t1 values ('a','a',default);
@@ -1621,12 +1621,12 @@
 set sql_warnings = 0;
 # IS NOT NULL
 set sql_warnings = 1;
-create table t1 (a int, b virtual bool as (a is not null));
+create table t1 (a int, b virtual int as (a is not null));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` int,
-  `b` VIRTUAL tinyint(1) AS (a is not null)
+  `b` VIRTUAL int AS (a is not null)
 ) ENGINE=InnoDB
 insert into t1 values (1,default);
 insert into t1 values (NULL,default);
@@ -1638,12 +1638,12 @@
 set sql_warnings = 0;
 # IS NULL
 set sql_warnings = 1;
-create table t1 (a int, b virtual bool as (a is null));
+create table t1 (a int, b virtual int as (a is null));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` int,
-  `b` VIRTUAL tinyint(1) AS (a is null)
+  `b` VIRTUAL int AS (a is null)
 ) ENGINE=InnoDB
 insert into t1 values (1,default);
 insert into t1 values (NULL,default);
@@ -1655,13 +1655,13 @@
 set sql_warnings = 0;
 # <=
 set sql_warnings = 1;
-create table t1 (a varchar(10), b varchar(10), c virtual bool as (a <= b));
+create table t1 (a varchar(10), b varchar(10), c virtual int as (a <= b));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` varchar(10),
   `b` varchar(10),
-  `c` VIRTUAL tinyint(1) AS (a <= b)
+  `c` VIRTUAL int AS (a <= b)
 ) ENGINE=InnoDB
 insert into t1 values ('b','a',default);
 insert into t1 values ('b','b',default);
@@ -1675,13 +1675,13 @@
 set sql_warnings = 0;
 # <
 set sql_warnings = 1;
-create table t1 (a varchar(10), b varchar(10), c virtual bool as (a < b));
+create table t1 (a varchar(10), b varchar(10), c virtual int as (a < b));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` varchar(10),
   `b` varchar(10),
-  `c` VIRTUAL tinyint(1) AS (a < b)
+  `c` VIRTUAL int AS (a < b)
 ) ENGINE=InnoDB
 insert into t1 values ('b','a',default);
 insert into t1 values ('b','b',default);
@@ -1695,12 +1695,12 @@
 set sql_warnings = 0;
 # NOT BETWEEN ... AND ...
 set sql_warnings = 1;
-create table t1 (a int, b virtual bool as (a not between 0 and 2));
+create table t1 (a int, b virtual int as (a not between 0 and 2));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` int,
-  `b` VIRTUAL tinyint(1) AS (a not between 0 and 2)
+  `b` VIRTUAL int AS (a not between 0 and 2)
 ) ENGINE=InnoDB
 insert into t1 values (-1,default);
 insert into t1 values (1,default);
@@ -1712,13 +1712,13 @@
 set sql_warnings = 0;
 # <>
 set sql_warnings = 1;
-create table t1 (a varchar(10), b varchar(10), c virtual bool as (a <> b));
+create table t1 (a varchar(10), b varchar(10), c virtual int as (a <> b));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` varchar(10),
   `b` varchar(10),
-  `c` VIRTUAL tinyint(1) AS (a <> b)
+  `c` VIRTUAL int AS (a <> b)
 ) ENGINE=InnoDB
 insert into t1 values ('b','a',default);
 insert into t1 values ('b','b',default);
@@ -1732,13 +1732,13 @@
 set sql_warnings = 0;
 # !=
 set sql_warnings = 1;
-create table t1 (a varchar(10), b varchar(10), c virtual bool as (a != b));
+create table t1 (a varchar(10), b varchar(10), c virtual int as (a != b));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` varchar(10),
   `b` varchar(10),
-  `c` VIRTUAL tinyint(1) AS (a != b)
+  `c` VIRTUAL int AS (a != b)
 ) ENGINE=InnoDB
 insert into t1 values ('b','a',default);
 insert into t1 values ('b','b',default);
@@ -2478,42 +2478,32 @@
 #
 # CAST FUNCTIONS AND OPERATORS
 #
-# CAST()
 set sql_warnings = 1;
-create table t1 (a int, b virtual int as (cast(a as unsigned)));
+create table t1 (a varchar(32), b virtual datetime as (cast(a as datetime)));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
-  `a` int,
-  `b` VIRTUAL int AS (cast(a as unsigned))
+  `a` varchar(32),
+  `b` VIRTUAL datetime AS (cast(a as datetime))
 ) ENGINE=InnoDB
-insert into t1 values (1,default);
-insert into t1 values (-1,default);
-Warnings:
-Warning	1264	Out of range value for column 'b' at row 1
+insert into t1 values ('2008-10-09',default);
 select * from t1;
 a	b
-1	1
--1	2147483647
+2008-10-09	2008-10-09 00:00:00
 drop table t1;
 set sql_warnings = 0;
-# Convert()
 set sql_warnings = 1;
-create table t1 (a int, b virtual int as (convert(a,unsigned)));
+create table t1 (a varchar(32), b virtual datetime as (convert(a, datetime)));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
-  `a` int,
-  `b` VIRTUAL int AS (convert(a,unsigned))
+  `a` varchar(32),
+  `b` VIRTUAL datetime AS (convert(a, datetime))
 ) ENGINE=InnoDB
-insert into t1 values (1,default);
-insert into t1 values (-1,default);
-Warnings:
-Warning	1264	Out of range value for column 'b' at row 1
+insert into t1 values ('2008-10-09',default);
 select * from t1;
 a	b
-1	1
--1	2147483647
+2008-10-09	2008-10-09 00:00:00
 drop table t1;
 set sql_warnings = 0;
 #

=== modified file 'tests/suite/vcol/r/vcol_supported_sql_funcs_myisam.result'
--- tests/suite/vcol/r/vcol_supported_sql_funcs_myisam.result	2008-09-19 11:49:17 +0000
+++ tests/suite/vcol/r/vcol_supported_sql_funcs_myisam.result	2008-10-09 08:33:03 +0000
@@ -981,12 +981,12 @@
 set sql_warnings = 0;
 # LIKE
 set sql_warnings = 1;
-create table t1 (a varchar(10), b virtual bool as (a like 'H%o'));
+create table t1 (a varchar(10), b virtual int as (a like 'H%o'));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` varchar(10),
-  `b` VIRTUAL tinyint(1) AS (a like 'H%o')
+  `b` VIRTUAL int AS (a like 'H%o')
 ) ENGINE=MyISAM
 insert into t1 values ('Hello',default);
 insert into t1 values ('MySQL',default);
@@ -1096,12 +1096,12 @@
 set sql_warnings = 0;
 # NOT LIKE
 set sql_warnings = 1;
-create table t1 (a varchar(10), b virtual bool as (a not like 'H%o'));
+create table t1 (a varchar(10), b virtual int as (a not like 'H%o'));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` varchar(10),
-  `b` VIRTUAL tinyint(1) AS (a not like 'H%o')
+  `b` VIRTUAL int AS (a not like 'H%o')
 ) ENGINE=MyISAM
 insert into t1 values ('Hello',default);
 insert into t1 values ('MySQL',default);
@@ -1278,13 +1278,13 @@
 set sql_warnings = 0;
 # STRCMP()
 set sql_warnings = 1;
-create table t1 (a varchar(9), b varchar(9), c virtual tinyint as (strcmp(a,b)));
+create table t1 (a varchar(9), b varchar(9), c virtual int as (strcmp(a,b)));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` varchar(9),
   `b` varchar(9),
-  `c` VIRTUAL tinyint(4) AS (strcmp(a,b))
+  `c` VIRTUAL int AS (strcmp(a,b))
 ) ENGINE=MyISAM
 insert into t1 values ('Hello','Hello', default);
 insert into t1 values ('Hello','Hello1', default);
@@ -1479,12 +1479,12 @@
 #
 # AND
 set sql_warnings = 1;
-create table t1 (a int, b virtual bool as (a>0 and a<2));
+create table t1 (a int, b virtual int as (a>0 and a<2));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` int,
-  `b` VIRTUAL tinyint(1) AS (a>0 and a<2)
+  `b` VIRTUAL int AS (a>0 and a<2)
 ) ENGINE=MyISAM
 insert into t1 values (-1,default);
 insert into t1 values (1,default);
@@ -1496,12 +1496,12 @@
 set sql_warnings = 0;
 # BETWEEN ... AND ... 
 set sql_warnings = 1;
-create table t1 (a int, b virtual bool as (a between 0 and 2));
+create table t1 (a int, b virtual int as (a between 0 and 2));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` int,
-  `b` VIRTUAL tinyint(1) AS (a between 0 and 2)
+  `b` VIRTUAL int AS (a between 0 and 2)
 ) ENGINE=MyISAM
 insert into t1 values (-1,default);
 insert into t1 values (1,default);
@@ -1547,13 +1547,13 @@
 set sql_warnings = 0;
 # <=>
 set sql_warnings = 1;
-create table t1 (a int, b int, c virtual bool as (a <=> b));
+create table t1 (a int, b int, c virtual int as (a <=> b));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` int,
   `b` int,
-  `c` VIRTUAL tinyint(1) AS (a <=> b)
+  `c` VIRTUAL int AS (a <=> b)
 ) ENGINE=MyISAM
 insert into t1 values (1,1,default);
 insert into t1 values (NULL,NULL,default);
@@ -1567,13 +1567,13 @@
 set sql_warnings = 0;
 # =
 set sql_warnings = 1;
-create table t1 (a varchar(10), b varchar(10), c virtual bool as (a=b));
+create table t1 (a varchar(10), b varchar(10), c virtual int as (a=b));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` varchar(10),
   `b` varchar(10),
-  `c` VIRTUAL tinyint(1) AS (a=b)
+  `c` VIRTUAL int AS (a=b)
 ) ENGINE=MyISAM
 insert into t1 values ('a','b',default);
 insert into t1 values ('a','a',default);
@@ -1585,13 +1585,13 @@
 set sql_warnings = 0;
 # >=
 set sql_warnings = 1;
-create table t1 (a varchar(10), b varchar(10), c virtual bool as (a >= b));
+create table t1 (a varchar(10), b varchar(10), c virtual int as (a >= b));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` varchar(10),
   `b` varchar(10),
-  `c` VIRTUAL tinyint(1) AS (a >= b)
+  `c` VIRTUAL int AS (a >= b)
 ) ENGINE=MyISAM
 insert into t1 values ('a','b',default);
 insert into t1 values ('a','a',default);
@@ -1603,13 +1603,13 @@
 set sql_warnings = 0;
 # >
 set sql_warnings = 1;
-create table t1 (a varchar(10), b varchar(10), c virtual bool as (a > b));
+create table t1 (a varchar(10), b varchar(10), c virtual int as (a > b));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` varchar(10),
   `b` varchar(10),
-  `c` VIRTUAL tinyint(1) AS (a > b)
+  `c` VIRTUAL int AS (a > b)
 ) ENGINE=MyISAM
 insert into t1 values ('a','b',default);
 insert into t1 values ('a','a',default);
@@ -1621,12 +1621,12 @@
 set sql_warnings = 0;
 # IS NOT NULL
 set sql_warnings = 1;
-create table t1 (a int, b virtual bool as (a is not null));
+create table t1 (a int, b virtual int as (a is not null));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` int,
-  `b` VIRTUAL tinyint(1) AS (a is not null)
+  `b` VIRTUAL int AS (a is not null)
 ) ENGINE=MyISAM
 insert into t1 values (1,default);
 insert into t1 values (NULL,default);
@@ -1638,12 +1638,12 @@
 set sql_warnings = 0;
 # IS NULL
 set sql_warnings = 1;
-create table t1 (a int, b virtual bool as (a is null));
+create table t1 (a int, b virtual int as (a is null));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` int,
-  `b` VIRTUAL tinyint(1) AS (a is null)
+  `b` VIRTUAL int AS (a is null)
 ) ENGINE=MyISAM
 insert into t1 values (1,default);
 insert into t1 values (NULL,default);
@@ -1655,13 +1655,13 @@
 set sql_warnings = 0;
 # <=
 set sql_warnings = 1;
-create table t1 (a varchar(10), b varchar(10), c virtual bool as (a <= b));
+create table t1 (a varchar(10), b varchar(10), c virtual int as (a <= b));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` varchar(10),
   `b` varchar(10),
-  `c` VIRTUAL tinyint(1) AS (a <= b)
+  `c` VIRTUAL int AS (a <= b)
 ) ENGINE=MyISAM
 insert into t1 values ('b','a',default);
 insert into t1 values ('b','b',default);
@@ -1675,13 +1675,13 @@
 set sql_warnings = 0;
 # <
 set sql_warnings = 1;
-create table t1 (a varchar(10), b varchar(10), c virtual bool as (a < b));
+create table t1 (a varchar(10), b varchar(10), c virtual int as (a < b));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` varchar(10),
   `b` varchar(10),
-  `c` VIRTUAL tinyint(1) AS (a < b)
+  `c` VIRTUAL int AS (a < b)
 ) ENGINE=MyISAM
 insert into t1 values ('b','a',default);
 insert into t1 values ('b','b',default);
@@ -1695,12 +1695,12 @@
 set sql_warnings = 0;
 # NOT BETWEEN ... AND ...
 set sql_warnings = 1;
-create table t1 (a int, b virtual bool as (a not between 0 and 2));
+create table t1 (a int, b virtual int as (a not between 0 and 2));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` int,
-  `b` VIRTUAL tinyint(1) AS (a not between 0 and 2)
+  `b` VIRTUAL int AS (a not between 0 and 2)
 ) ENGINE=MyISAM
 insert into t1 values (-1,default);
 insert into t1 values (1,default);
@@ -1712,13 +1712,13 @@
 set sql_warnings = 0;
 # <>
 set sql_warnings = 1;
-create table t1 (a varchar(10), b varchar(10), c virtual bool as (a <> b));
+create table t1 (a varchar(10), b varchar(10), c virtual int as (a <> b));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` varchar(10),
   `b` varchar(10),
-  `c` VIRTUAL tinyint(1) AS (a <> b)
+  `c` VIRTUAL int AS (a <> b)
 ) ENGINE=MyISAM
 insert into t1 values ('b','a',default);
 insert into t1 values ('b','b',default);
@@ -1732,13 +1732,13 @@
 set sql_warnings = 0;
 # !=
 set sql_warnings = 1;
-create table t1 (a varchar(10), b varchar(10), c virtual bool as (a != b));
+create table t1 (a varchar(10), b varchar(10), c virtual int as (a != b));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
   `a` varchar(10),
   `b` varchar(10),
-  `c` VIRTUAL tinyint(1) AS (a != b)
+  `c` VIRTUAL int AS (a != b)
 ) ENGINE=MyISAM
 insert into t1 values ('b','a',default);
 insert into t1 values ('b','b',default);
@@ -2478,42 +2478,32 @@
 #
 # CAST FUNCTIONS AND OPERATORS
 #
-# CAST()
 set sql_warnings = 1;
-create table t1 (a int, b virtual int as (cast(a as unsigned)));
+create table t1 (a varchar(32), b virtual datetime as (cast(a as datetime)));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
-  `a` int,
-  `b` VIRTUAL int AS (cast(a as unsigned))
+  `a` varchar(32),
+  `b` VIRTUAL datetime AS (cast(a as datetime))
 ) ENGINE=MyISAM
-insert into t1 values (1,default);
-insert into t1 values (-1,default);
-Warnings:
-Warning	1264	Out of range value for column 'b' at row 1
+insert into t1 values ('2008-10-09',default);
 select * from t1;
 a	b
-1	1
--1	2147483647
+2008-10-09	2008-10-09 00:00:00
 drop table t1;
 set sql_warnings = 0;
-# Convert()
 set sql_warnings = 1;
-create table t1 (a int, b virtual int as (convert(a,unsigned)));
+create table t1 (a varchar(32), b virtual datetime as (convert(a, datetime)));
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
-  `a` int,
-  `b` VIRTUAL int AS (convert(a,unsigned))
+  `a` varchar(32),
+  `b` VIRTUAL datetime AS (convert(a, datetime))
 ) ENGINE=MyISAM
-insert into t1 values (1,default);
-insert into t1 values (-1,default);
-Warnings:
-Warning	1264	Out of range value for column 'b' at row 1
+insert into t1 values ('2008-10-09',default);
 select * from t1;
 a	b
-1	1
--1	2147483647
+2008-10-09	2008-10-09 00:00:00
 drop table t1;
 set sql_warnings = 0;
 #

